@@ -1,6 +1,6 @@
 "pargno" <-
 function(lmom,checklmom=TRUE,...) {
-    para <- vector(mode="numeric", length=3)
+    para <- rep(NA,3)
     names(para) <- c("xi","alpha","kappa")
     "erf" <- function(x) 2 * pnorm(x * sqrt(2)) - 1
 
@@ -14,7 +14,7 @@ function(lmom,checklmom=TRUE,...) {
     #  SMALL IS USED TO TEST WHETHER SKEWNESS IS EFFECTIVELY ZERO
     SMALL <- 1e-8
 
-    if(length(lmom$L1) == 0) { # convert to named L-moments
+    if(length(lmom$L1) == 1) { # convert to named L-moments
       lmom <- lmorph(lmom)     # nondestructive conversion!
     }
     if(checklmom & ! are.lmom.valid(lmom)) {
@@ -22,28 +22,30 @@ function(lmom,checklmom=TRUE,...) {
        return()
     }
 
-    T3 <- lmom$TAU3
-    if(abs(T3) >= 0.95) {
-      warning("L-SKEW IS TOO LARGE FOR ROUTINE")
-      para[1] = 0
-      para[2] = -1
-      para[3] = 0
-      return(list(type = 'gno', para = para))
+    T3 <- lmom$ratios[3]; SGN <- sign(T3)
+    if(abs(T3) > 0.95) {
+      warning("L-skew is too large, truncating L-skew to 0.95")
+      T3 <- SGN*0.95
+      #para[1] = 0
+      #para[2] = -1
+      #para[3] = 0
+      #return(list(type = 'gno', para = para))
     }
     if(abs(T3) <= SMALL) {
-      para[1] = lmom$L1
-      para[2] = lmom$L2*sqrt(pi)
-      para[3] = 0
+      para[1] <- lmom$lambdas[1]
+      para[2] <- lmom$lambdas[2]*sqrt(pi)
+      para[3] <- 0
       return(list(type = 'gno', para = para))
+    } else {
+      TT <- T3*T3
+      K <- -T3*(A0+TT*(A1+TT*(A2+TT*A3)))/(1+TT*(B1+TT*(B2+TT*B3)))
+      E <- exp(0.5*K*K)
+      A <-  lmom$lambdas[2]*K/(E*erf(0.5*K))
+      XI <- lmom$lambdas[1]+A*(E-1)/K
+      para[1] <- XI
+      para[2] <- A
+      para[3] <- K
+      return(list(type = 'gno', para = para, source="pargno"))
     }
-    TT <- T3*T3
-    K <- -T3*(A0+TT*(A1+TT*(A2+TT*A3)))/(1+TT*(B1+TT*(B2+TT*B3)))
-    E <- exp(0.5*K*K)
-    A <- lmom$L2*K/(E*erf(0.5*K))
-    XI <- lmom$L1+A*(E-1)/K
-    para[1] <- XI
-    para[2] <- A 
-    para[3] <- K 
-    return(list(type = 'gno', para = para, source="pargno")) 
 }
 
